@@ -1,6 +1,9 @@
-use crate::Result;
-use crate::{low_level::LowLevel, Dict};
-use std::{path::PathBuf, sync::Arc};
+use crate::types::BoringResult;
+use crate::low_level::LowLevel;
+use crate::dict::Dict;
+
+use std::path::PathBuf;
+use std::sync::Arc;
 
 /// A database full of maps.
 pub struct Database {
@@ -9,26 +12,26 @@ pub struct Database {
 
 impl Database {
     /// Opens a database given a filename.
-    pub fn open(path: impl Into<PathBuf>) -> Result<Self> {
-        let ll = LowLevel::open(path)?;
+    pub fn open(path: impl Into<PathBuf>) -> BoringResult<Self> {
+        let low_level: LowLevel = LowLevel::open(path)?;
         Ok(Self {
-            low_level: Arc::new(ll),
+            low_level: Arc::new(low_level),
         })
     }
 
     /// Opens a dictionary given its name. Creates a new empty map if the map doesn't exist
-    pub fn open_dict(&self, name: &str) -> Result<Dict> {
-        self.low_level.transaction(|txn| {
-            txn.execute(
+    pub fn open_dict(&self, name: &str) -> BoringResult<Dict> {
+        self.low_level.transaction(|transaction| {
+            transaction.execute(
                 &format!(
                     "create table if not exists {} (key BLOB PRIMARY KEY, value BLOB NOT NULL) without rowid",
                     name
                 ),
                 [],
             )?;
-            txn.commit()?;
+            transaction.commit()?;
             Ok(())
         })?;
         Ok(Dict::new(self.low_level.clone(), name))
     }
-}
+}
\ No newline at end of file
